@@ -1,8 +1,8 @@
 /*
  *  WINGs WMConnection function library
- * 
- *  Copyright (c) 1999-2002 Dan Pascu
- * 
+ *
+ *  Copyright (c) 1999-2003 Dan Pascu
+ *
  *  This program is free software; you can redistribute it and/or modify
  *  it under the terms of the GNU General Public License as published by
  *  the Free Software Foundation; either version 2 of the License, or
@@ -65,11 +65,13 @@
 #endif
 
 /* Stuff for setting the sockets into non-blocking mode. */
-/*#ifdef	__POSIX_SOURCE
+/*
+#ifdef	__POSIX_SOURCE
 # define NONBLOCK_OPT           O_NONBLOCK
 #else
 # define NONBLOCK_OPT           FNDELAY
-#endif*/
+#endif
+*/
 
 #define NONBLOCK_OPT            O_NONBLOCK
 
@@ -121,6 +123,7 @@ typedef struct W_Connection {
     char *protocol;
 
     Bool closeOnRelease;
+    Bool shutdownOnClose;
     Bool wasNonBlocking;
     Bool isNonBlocking;
 
@@ -173,6 +176,8 @@ sendTimeout(void *cdata)
         clearOutputQueue(cPtr);
         cPtr->state = WCTimedOut;
         cPtr->timeoutState = WCTWhileSending;
+        /* // should we close it no matter what (after calling the didTimeout
+           // delegate)? -Dan */
         if (cPtr->delegate && cPtr->delegate->didTimeout) {
             (*cPtr->delegate->didTimeout)(cPtr->delegate, cPtr);
         } else {
@@ -192,9 +197,10 @@ inputHandler(int fd, int mask, void *clientData)
         return;
 
     if ((mask & WIWriteMask)) {
+        int result;
+
         if (cPtr->state == WCInProgress) {
             Bool failed;
-            int	result;
             int len = sizeof(result);
 
             WCErrorCode = 0;
@@ -228,7 +234,10 @@ inputHandler(int fd, int mask, void *clientData)
             if (failed)
                 return;
         } else if (cPtr->state == WCConnected) {
-            WMFlushConnection(cPtr);
+            result = WMFlushConnection(cPtr);
+            if (result>0 && cPtr->delegate && cPtr->delegate->canResumeSending) {
+                (*cPtr->delegate->canResumeSending)(cPtr->delegate, cPtr);
+            }
         }
     }
 
@@ -321,7 +330,7 @@ getSocketAddress(char* name, char* service, char* protocol)
 #ifndef	HAVE_INET_ATON
         if ((socketaddr.sin_addr.s_addr = inet_addr(name)) == INADDR_NONE) {
 #else
-        if (inet_aton(name, &socketaddr.sin_addr) == 0) {
+            if (inet_aton(name, &socketaddr.sin_addr) == 0) {
 #endif
             WMReleaseHost(host);
             return NULL;
@@ -376,6 +385,7 @@ createConnectionWithSocket(int sock, Bool closeOnRelease)
     cPtr->sendTimeout.timeout = DefaultTimeout;
     cPtr->sendTimeout.handler = NULL;
     cPtr->closeOnRelease = closeOnRelease;
+    cPtr->shutdownOnClose = 1;
     cPtr->outputQueue =
         WMCreateArrayWithDestructor(16, (WMFreeDataProc*)WMReleaseData);
     cPtr->state = WCNotConnected;
@@ -411,8 +421,8 @@ WMCreateConnectionWithSocket(int sock, Bool closeOnRelease)
     cPtr->isNonBlocking = cPtr->wasNonBlocking;
 
     /* some way to find out if it is connected, and binded. can't find
-       if it listens though!!!
-    */  
+     if it listens though!!!
+     */
 
     size = sizeof(clientname);
     n = getpeername(sock, (struct sockaddr*) &clientname, &size);
@@ -627,7 +637,9 @@ void
 WMDestroyConnection(WMConnection *cPtr)
 {
     if (cPtr->closeOnRelease && cPtr->sock>=0) {
-        shutdown(cPtr->sock, SHUT_RDWR);
+        if (cPtr->shutdownOnClose) {
+            shutdown(cPtr->sock, SHUT_RDWR);
+        }
         close(cPtr->sock);
     }
 
@@ -648,7 +660,9 @@ void
 WMCloseConnection(WMConnection *cPtr)
 {
     if (cPtr->sock>=0) {
-        shutdown(cPtr->sock, SHUT_RDWR);
+        if (cPtr->shutdownOnClose) {
+            shutdown(cPtr->sock, SHUT_RDWR);
+        }
         close(cPtr->sock);
         cPtr->sock = -1;
     }
@@ -743,10 +757,18 @@ WMEnqueueConnectionData(WMConnection *cPtr, WMData *data)
 }
 
 
+/*
+ * Return value:
+ * -1 - not connected or connection died while sending
+ *  0 - couldn't send the data (or part of it). data is saved in a queue
+ *      and will be sent when possible. after it is sent the canResumeSending
+ *      callback will be called.
+ *  1 - data was succesfully sent
+ */
 int
 WMSendConnectionData(WMConnection *cPtr, WMData *data)
 {
-    int bytes, pos, len, totalTransfer;
+    int bytes, pos, len;
     TimeoutData *tPtr = &cPtr->sendTimeout;
     const unsigned char *dataBytes;
 
@@ -767,8 +789,6 @@ WMSendConnectionData(WMConnection *cPtr, WMData *data)
             return 0;
     }
 
-    totalTransfer = 0;
-
     while (WMGetArrayItemCount(cPtr->outputQueue) > 0) {
         data = WMGetFromArray(cPtr->outputQueue, 0);
         dataBytes = (const unsigned char *)WMDataBytes(data);
@@ -793,7 +813,7 @@ WMSendConnectionData(WMConnection *cPtr, WMData *data)
                             WMAddInputHandler(cPtr->sock, WIWriteMask,
                                               inputHandler, cPtr);
                     }
-                    return totalTransfer;
+                    return 0;
                 default:
                     WCErrorCode = errno;
                     cPtr->state = WCDied;
@@ -804,7 +824,6 @@ WMSendConnectionData(WMConnection *cPtr, WMData *data)
                 }
             }
             pos += bytes;
-            totalTransfer += bytes;
         }
         WMDeleteFromArray(cPtr->outputQueue, 0);
         cPtr->bufPos = 0;
@@ -812,13 +831,18 @@ WMSendConnectionData(WMConnection *cPtr, WMData *data)
             WMDeleteTimerHandler(tPtr->handler);
             tPtr->handler = NULL;
         }
-        if (cPtr->handler.write) {
-            WMDeleteInputHandler(cPtr->handler.write);
-            cPtr->handler.write = NULL;
-        }
+        /*if (cPtr->handler.write) {
+         WMDeleteInputHandler(cPtr->handler.write);
+         cPtr->handler.write = NULL;
+         }*/
     }
 
-    return totalTransfer;
+    if (cPtr->handler.write) {
+        WMDeleteInputHandler(cPtr->handler.write);
+        cPtr->handler.write = NULL;
+    }
+
+    return 1;
 }
 
 
@@ -952,6 +976,13 @@ WMSetConnectionCloseOnExec(WMConnection *cPtr, Bool flag)
 }
 
 
+void
+WMSetConnectionShutdownOnClose(WMConnection *cPtr, Bool flag)
+{
+    cPtr->shutdownOnClose = ((flag==0) ? 0 : 1);
+}
+
+
 void*
 WMGetConnectionClientData(WMConnection *cPtr)
 {
