@@ -1,8 +1,8 @@
 /*
  *  Window Maker window manager
  *
- *  Copyright (c) 1997, 1998 Alfredo K. Kojima
- * 
+ *  Copyright (c) 1997-2003 Alfredo K. Kojima
+ *
  *  This program is free software; you can redistribute it and/or modify
  *  it under the terms of the GNU General Public License as published by
  *  the Free Software Foundation; either version 2 of the License, or
@@ -15,7 +15,7 @@
  *
  *  You should have received a copy of the GNU General Public License
  *  along with this program; if not, write to the Free Software
- *  Foundation, Inc., 59 Temple Place - Suite 330, Boston, MA 02111-1307, 
+ *  Foundation, Inc., 59 Temple Place - Suite 330, Boston, MA 02111-1307,
  *  USA.
  */
 
@@ -28,25 +28,26 @@
 /* window */
 #define WKBD_MINIATURIZE	3
 #define WKBD_HIDE		4
-#define WKBD_MAXIMIZE		5
-#define WKBD_VMAXIMIZE		6
-#define WKBD_HMAXIMIZE		7
-#define WKBD_SELECT		8
+#define WKBD_HIDE_OTHERS        5
+#define WKBD_MAXIMIZE           6
+#define WKBD_VMAXIMIZE          7
+#define WKBD_HMAXIMIZE          8
+#define WKBD_SELECT             9
 /* Clip */
-#define WKBD_CLIPLOWER		9
-#define WKBD_CLIPRAISE		10
-#define WKBD_CLIPRAISELOWER	11
+#define WKBD_CLIPLOWER          10
+#define WKBD_CLIPRAISE		11
+#define WKBD_CLIPRAISELOWER	12
 /* window */
-#define WKBD_RAISE		12
-#define WKBD_LOWER		13
-#define WKBD_RAISELOWER		14
-#define WKBD_MOVERESIZE		15
-#define WKBD_SHADE		16
+#define WKBD_RAISE		13
+#define WKBD_LOWER		14
+#define WKBD_RAISELOWER		15
+#define WKBD_MOVERESIZE		16
+#define WKBD_SHADE		17
 /* window, menu */
-#define WKBD_CLOSE		17
+#define WKBD_CLOSE		18
 /* window */
-#define WKBD_FOCUSNEXT		18
-#define WKBD_FOCUSPREV		19
+#define WKBD_FOCUSNEXT		19
+#define WKBD_FOCUSPREV          20
 
 #define WKBD_WORKSPACE1		21
 #define WKBD_WORKSPACE2		22
@@ -78,11 +79,21 @@
 #define WKBD_SWITCH_SCREEN      45
 
 #ifdef KEEP_XKB_LOCK_STATUS
-# define WKBD_TOGGLE             46
-# define WKBD_LAST               47
+# define WKBD_TOGGLE		46
+# define WKBD_TMP		47
 #else
-# define WKBD_LAST               46
-#endif /* KEEP_XKB_LOCK_STATUS */
+# define WKBD_TMP		46
+#endif
+
+#ifdef VIRTUAL_DESKTOP
+# define WKBD_VDESK_LEFT	WKBD_TMP
+# define WKBD_VDESK_RIGHT	(WKBD_TMP+1)
+# define WKBD_VDESK_UP		(WKBD_TMP+2)
+# define WKBD_VDESK_DOWN	(WKBD_TMP+3)
+# define WKBD_LAST		(WKBD_TMP+4)
+#else
+# define WKBD_LAST		WKBD_TMP
+#endif /* VIRTUAL_DESKTOP */
 
 
 typedef struct WShortKey {
